#Copyright (c) 2012 Jose Luis Naranjo Gomez
#    This file is part of Flashcards
#
#    Flashcards is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    Flashcards is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Flashcards.  If not, see <http://www.gnu.org/licenses/>.

import os
import sys
import sqlite3

class db_op(object):
    def __init__(self,path):
        
        self.db_path = path

        self.con = sqlite3.connect(self.db_path)
        self.cur = self.con.cursor()
        self.tables_exist = False
        self.index = self.get_index() #List of tables in the database
        
    def refresh(self): #Working
        """Reload the initializer for more up to date information"""
        
        self.__init__(self.db_path)

    def close(self): #Working
        """For simple connection closing"""
        
        self.con.close()
        
    def get_index(self): #Working
        """Returns a list of all of the tables in the database"""
        
        sqlite_master = self.cur.execute("SELECT name FROM sqlite_master")
        index = []
        for table in sqlite_master:
            if table:
                self.tables_exist = True
            index.append(table[0])
        return index

    def select_tbl(self,msg="select",disp=True): #Working
        """Returns the name of the table that the user specifies. Depends on the get_index method"""
        
        self.refresh()
        if disp:
            print "Which table would you like to %s?" % msg
            
        count = 1
        tbl_track = [None]
        for table in self.index:
            if not table or table == '': #Not working
                print "No tables available!"
                
            print "%d:\t%s"% (count,table)
            tbl_track.append(table)
            count += 1
        try:
            selection = raw_input("> ")
            if selection == "exit" or selection == 'end':
                self.close()
                sys.exit(0)
                
            selection = int(selection)
        except ValueError:
            print("You need to tell me which set of flashcards you want to %s!" % msg)
            self.close()
            sys.exit(0)
            
        return tbl_track[selection]
        
    def delete_tbl(self, selection=None): #Working
        """Deletes the table that the user specifies in the select_tbl method, if it exists."""
        self.refresh()
        
        if not selection:
            selection = self.select_tbl("delete")
        
        try:
            self.cur.execute("drop table %s" % selection)
        except sqlite3.OperationalError:
            print "%s doesn't exist!" % selection
        self.con.commit()
        
    def create_tbl(self,name = None): #Working
        """Creates a user-named table with default parameter"""
    
        if not name:
            print "What would you like to name your table?"
            name = raw_input("> ")
            
        try:
            self.cur.execute("create table if not exists %s(id integer, question text, answer text)" % name)
            print "Created table if it didn't exist:\t%s" % name
        except sqlite3.OperationalError:
            print "SQLITE DATABASE ERROR"
            print "Make sure your database name has no spaces or odd characters!"
        self.con.commit()
        self.refresh()
        

        
    def delete_all(self): #Working
        """WARNING: Deletes all of the tables in the database!"""
        
        self.refresh()
        for table in self.index:
            self.delete_tbl(table)
            
    def write_to_tbl(self, ID, question, answer, selection=None):
        """Writes three values (1st 2nd and 3rd parameters) to the given table (4th optional parameter)
        If not table is given, activates select_tbl menu"""
    
        if not selection:
            selection = self.select_tbl("write to")
            
        sql_stmt = "insert into %s values(?,?,?)" % selection
        self.cur.execute(sql_stmt, (ID, question, answer))
        self.con.commit()
        self.refresh()
    
    def read_from_tbl(self, table=None):
        """Reads from the given table. Provides an alternate menu (select_tbl) if no table is given."""
        if not table:
            table = self.select_tbl("read from")
        
        reader = self.cur.execute("select * from %s" % table)
        values = []
        for row in reader:
            ID = row[0]
            question = row[1]
            answer = row[2]
            
            format = (ID,question,answer)
            values.append(format)
        return values
        
    def print_values(self, table):
        """Prints out all of the values in the given table."""
        
        entries = self.read_from_tbl(table)
        for entry in entries:
            ID = entry[0]
            question = entry[1]
            answer = entry[2]
                
            print "ID:      \t%s" % ID
            print "Question:\t%s" % question
            print "Answer:  \t%s\n" % answer
        
            
    def delete_from_tbl(self, table=None, value=None):
        """Deletes the selected value from the given table."""
        
        if not table:
            table = self.select_tbl("delete from")
            
        if not value:
            self.print_values(table) #Prints out the values in the table
            
            print "Which value in %s would you like to delete?" % table

            value = int(raw_input("ID:\t"))
            
        self.cur.execute("delete from %s where id==%s" % (table,value))
        print "Deleted question number %d." % value
        self.con.commit()
            

        
        

#db = db_op()

#db.refresh() #Reloads db info

#print db.index #List of all of the tables in the db
#db.select_tbl(msg) #Menu for choosing a table in the db, returns table name

#   TABLE METHODS
#db.create_tbl(name) #Creates a table in the db
#db.delete_tbl(name=None) #Deletes a table in the db
#db.delete_all() #Deletes all of the tables in the db

#   VALUE METHODS
#db.write_to_tbl(id,question,answer,table) #For inserting values to a table
#db.read_from_tbl(table=None) #Retuns list of tuples from that table. Each tuple is a set -  (id, question, answer)
#db.delete_from_tbl(table=None) #Deletes a value in the table
#db.print_values(table=None) #Prints all of the values in the table

#db.con.commit()
#db.close()
#list_tables() #Lists all available tables



#Copyright (c) 2012 Jose Luis Naranjo Gomez
#    This file is part of Flashcards
#
#    Flashcards is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    Flashcards is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Flashcards.  If not, see <http://www.gnu.org/licenses/>.


import os
from sys import exit,platform
from random import shuffle
import db_api
import configure

db_path = configure.db_path
path = db_path

db = db_api.db_op(db_path)



#db.refresh() #Reloads db info

#print db.index #List of all of the tables in the db
#db.select_tbl(msg) #Menu for choosing a table in the db, returns table name

#   TABLE METHODS
#db.create_tbl(name) #Creates a table in the db
#db.delete_tbl(name=None) #Deletes a table in the db
#db.delete_all() #Deletes all of the tables in the db

#   VALUE METHODS
#db.write_to_tbl(id,question,answer,table) #For inserting values to a table
#db.read_from_tbl(table=None) #Retuns list of tuples from that table. Each tuple is a set -  (id, question, answer)
#db.delete_from_tbl(table=None) #Deletes a value in the table
#db.print_values(table=None) #Prints all of the values in the table

#db.con.commit()
#db.close()
#list_tables() #Lists all available tables

def msg(message):
    print "="*72
    print message
    
#========================================================================

def use_set(table=None):
    if not table:
        table = db.select_tbl("use")
        
    key = db.read_from_tbl(table)
    
    if not key:
        print("No flashcards stored in this set!")
        
    shuffle(key)
    
    breakers = "end exit break close leave stop".split()
    
    for each in key:
    
        ID = each[0]
        question = each[1]
        answer = str(each[2])
        answers = answer.split(",")
        
        print "\t\tQUESTION #%d" % ID
        print "Question:\t%s" % question
        response = raw_input("> ")
        
        if response in breakers:
            break
            
        correct = False
        for the_answer in answers:
            if response == the_answer:
                correct = True
        
        
        if correct:
            print "\nCorrect!"
       
        if not correct:
            print "\nThe correct response was any of the following:"
            answers = " | ".join(answers)
            print "\t",answers
        print "-"*72
        
def create_set(name=None):
    if not name:
        print "What would you like this set of flashcards to be called?"
        print "No spaces or odd characters allowed!"
        name = raw_input("> ")
        
    db.create_tbl(name)


def edit_set(question,answer,table=None):
    if not table:
        table = db.select_tbl("edit")


    entries = db.read_from_tbl(table) #Retuns list of tuples from that table. Each tuple is a set -  (id, question, answer)
    if len(entries) == 0:
        current_id = 1
    if len(entries) > 0:
        entry_ids = []
        for entry in entries:
            ID = entry[0]
            entry_ids.append(ID)
        entry_ids.sort()
        current_id = len(entries) + 1
        
    
    db.write_to_tbl(current_id,question,answer,table)
        



def erase_set():
    table = db.select_tbl("erase")
    db.delete_tbl(table)
    return table
    
def erase_all_sets():
    
    db.refresh()
    print "Deleted the following sets of flashcards:"
    for table in db.index:
        print "\t%s" % table
    db.delete_all()
    
def close():
    db.close()
    exit(0)



#!/usr/bin/env python

#Copyright (c) 2012 Jose Luis Naranjo Gomez
#    This file is part of Flashcards
#
#    Flashcards is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    Flashcards is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Flashcards.  If not, see <http://www.gnu.org/licenses/>.

from sys import exit, argv
import os
import argparse
import db_api
import quiz_csv
import quiz_sql
import configure

def delete():
    print "Are you sure (Y/N)?"
    ask = raw_input("> ").lower()
    data_path = os.path.join(os.getcwd(), "data.csv")
    if ask == 'n' or ask == 'no':
        exit(0)
    else:
        txt = open(data_path, 'w')
        txt.truncate()
        txt.close()
        print "Erased '%s'." % data_path

def adder(table):
    breakers = "end exit break close leave stop".split()
    while True:
        question = raw_input("Question:\t")
        if question in breakers: 
            break
            
        answer   = raw_input("Answer  :\t")
        if answer in breakers:
            break
            
        quiz_sql.edit_set(question, answer,table)
        print "-"*72

def sub_menu_sqlite3(table):
    print "Loaded %s set of flashcards." % table
    print "="*72,"\n"
    breakers = "end exit break close leave stop".split()
    
    while True:
        print "\n\t%s MENU" % table.upper()
        print "1: Use flashcards" #Working
        print "2: Add flashcards" #Working
        print "3: Delete flashcards" #Working
        print "4: Go back to the main menu" #Working
        print "5: exit\n" #Working
        
        ask = raw_input("> ").lower()
        print "="*72
        
        if ask == '1':
            quiz_sql.use_set(table)
        
        if ask == '2':
            adder(table)
            
        if ask == '3':
            quiz_sql.db.delete_from_tbl(table)
        
        if ask == '4':
            break
        
        if ask in breakers or ask == '5':
            quiz_sql.close()
            
        print "="*72
def menu_sqlite3(load=None):
    print "Connected to %s" % quiz_sql.path
    print "="*72,"\n\n"
    
    if load:
        sub_menu_sqlite3(load)
        load = False
        
    if not load:
        while True:
            print "\tMAIN MENU"
            print "1: Load a set of flashcards" #Working
            print "2: Create a set of flashcards" #Working
            print "3: Delete a set of flashcards" #Working
            print "4: Delete all sets of flashcards" #Working
            print "5: exit\n" #Works
            
            ask = raw_input("> ").lower()
            #print "="*72

            if ask == 'list':
                for table in quiz_sql.db.index:
                    print table
                
            if ask == '1':
                table = quiz_sql.db.select_tbl("load")
                sub_menu_sqlite3(table)
                
            if ask == '2':
                quiz_sql.create_set()
                

            if ask == '3':
                table = quiz_sql.erase_set()
                print "Deleted %s set." % table
                
            if ask == '4':
                print "="*72
                print "Are you sure? (y\\n)"
                check = raw_input(">\n")
                if check.lower() == 'n':
                    print "="*72
                    continue
                quiz_sql.erase_all_sets()
                
            if ask.lower() == 'exit' or ask == 'end' or ask == '5':
                quiz_sql.close()
                
            print "="*72
def menu_csv():
    while True:
        print "1: Enter quiz mode"
        print "2: Enter quiz editor"
        print "3: Erase current quiz"
        print "4: Exit"
        ask = raw_input("> ").lower()
        
       
        
        if ask == 'end':
            break
            
        if ask.lower() == 'exit' or ask == 'end' or ask == '4':
            exit(0)
            
        if ask == '1' or ask == "enter quiz mode":
            quizzer = quiz_csv.reader()
            quizzer.start()
            
        if ask == '2' or ask == 'enter quiz editor':
            writer = quiz_csv.writer()
            writer.start()
            
        if ask == '3' or ask == 'erase current quiz':
            delete()
            
        print "="*72
def get_args():
    parser = argparse.ArgumentParser(
        description="Purpose: A command line flashcard interface",
        epilog="Developed by Luis Naranjo.\nSource is available at https://launchpad.net/pyflashcards/2.0"
    )

    parser.add_argument('-v','--version',  action='version', version='%(prog)s 2.3')

    parser.add_argument(
    '-c', '--csv',
    action='store_true',
    help="Use a csv file in the current working directory for storing data.",
    )

    parser.add_argument(
    '-s', '--sql',
    action='store_true',
    help="Use a sqlite3 database in your home directory for storing data.",
    )
    
    parser.add_argument(
    '-ls','--list',
    action='store_true',
    help="List all of the available sets of flashcards",
    dest="list",
    )
    
    parser.add_argument(
    '-rm', '--remove',
    help="Remove a set of flashcards",
    dest="remove",
    )
    
    parser.add_argument(
    '-l', '--load',
    help='Load a specific table of flashcards from sql db.',
    dest="load"
    )
    
    parser.add_argument(
    '-u', '--use',
    help="Use a set of flashcards",
    dest="use",
    )
    
    parser.add_argument(
    '-m', '--make',
    help="Make a set of flashcards",
    dest="make",
    )
    
    parser.add_argument(
    '-a', '--add',
    help="Add to a set of flashcards",
    dest="add",
    )
    

    
    args = parser.parse_args()
    
    csv = args.csv
    sql = args.sql
    listy = args.list
    load = args.load
    use = args.use
    remove = args.remove
    make = args.make
    add = args.add
    return (csv,sql,listy,load,use,remove,make,add)
    
    

class conf(object):
    """
    Reads the settings file, and creates it with false values if it doesn't exist and sets vals to false if file empty.
    Returns a dict with booleans. conf.settings['csv'] and conf.settings['sql']
    Requires no parameters. Stand-alone. Assumes conf file is in hidden flashcards folder and is called 'defaults.conf'
    """
    def __init__(self):
        
        self.home_path = os.path.expanduser("~")
        self.path = os.path.join(self.home_path,".flashcards/defaults.conf")
        self.file_exists = os.path.isfile(self.path)
        self.settings = dict()
        self.parse()
        self.clean()

    def parse(self):
    
        if self.file_exists:
            config = ConfigObj(self.path)
            
            try:
                csv = config['csv']
                sql = config['sql']
            except:
                csv = None
                sql = None
                self.file_exists = False
                
            self.settings['sql'] = sql
            self.settings['csv'] = csv
            
        if not self.file_exists:
            default = False
            config = ConfigObj()
            config.filename = self.path
            config['sql'] = default
            config['csv'] = default
            config.write()
            self.file_exists = True
            self.parse()

    def clean(self):
        settings = self.settings
        for keyword in settings:
            stop_words = "true false True False".split()
            value = settings[keyword]
            
            if value == 'true' or value == "True":
                settings[keyword] = True
                
            if value == 'false' or value == "False":
                settings[keyword] = False



def menu(args=get_args()):
    
    csv = args[0]
    sql = args[1]
    list = args[2]
    load = args[3]
    use = args[4]
    remove = args[5]
    make = args[6]
    add = args[7]
    
    if csv:
        menu_csv()
    if sql:
        menu_sqlite3()
    
    if list:
        index = quiz_sql.db.index
        count = 1
        print "Flashcard sets available:"
        for table in index:
            print "%d:\t%s" % (count,table)
            count += 1
        
    if load:
        menu_sqlite3(load)
        
    if use:
        quiz_sql.use_set(use)
        
    if remove:
        quiz_sql.db.delete_tbl(remove)
        #print "Deleted %s set." % remove
        
    if make:
        quiz_sql.db.create_tbl(make)
        
    if add:
        adder(add)
        
    if not csv and not sql and not list and not load and not use and not remove and not make and not add:
        print "What type of data do you want to use?"
        print "1: Database"
        print "\tStores quizzes in database"
        print "2: CSV file"
        print "\tGenerates quiz file"
        print "3: exit"
        
        mode = raw_input("> ")
        
        if mode == 'end' or mode == 'exit' or mode == '3':
            exit(0)
        if mode == '1':
            menu_sqlite3()
        if mode == '2':
            menu_csv()


def main():
    data = configure.conf()
    mode = data.settings
    csv = mode['csv']
    sql = mode['sql']
    
    args = get_args()
    
    if args[0] or args[1]: #csv and sqlflag
        menu(args)
        exit(0)
        
    if csv and not sql:
        menu_csv()
        
    if sql and not csv:
        menu_sqlite3()
        
    if (not sql and not csv) or (csv and sql):
        menu(args)
        
if __name__ == "__main__":
    main()



#Copyright (c) 2012 Jose Luis Naranjo Gomez
#    This file is part of Flashcards
#
#    Flashcards is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    Flashcards is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Flashcards.  If not, see <http://www.gnu.org/licenses/>.

import os
from sys import platform
from configobj import ConfigObj


home_path = os.path.expanduser("~")
if platform == 'linux2' or platform == 'darwin':
    documents = os.path.join(home_path, 'Documents')
    ROOT = os.path.join(documents, 'flashcards')
    

if platform == 'win32':
    documents = os.path.join(home_path, 'Documents')
    ROOT = os.path.join(documents, 'flashcards')
    
if not os.path.isdir(ROOT):
    os.mkdir(ROOT)
    
    
db_path = os.path.join(ROOT, "flashcards.db")

class conf(object):
    """
    Reads the settings file, and creates it with false values if it doesn't exist and sets vals to false if file empty.
    Returns a dict with booleans. conf.settings['csv'] and conf.settings['sql']
    Requires no parameters. Stand-alone. Assumes conf file is in hidden flashcards folder and is called 'defaults.conf'
    """
    def __init__(self):
        self.home_path = os.path.expanduser("~")
        self.path = os.path.join(ROOT, "settings.conf")
        self.file_exists = os.path.isfile(self.path)
        self.settings = dict()
        self.parse()
        self.clean()

    def parse(self):
    
        if self.file_exists:
            config = ConfigObj(self.path)
            
            try:
                csv = config['csv']
                sql = config['sql']
            except:
                csv = None
                sql = None
                self.file_exists = False
                
            self.settings['sql'] = sql
            self.settings['csv'] = csv
            
        if not self.file_exists:
            default = False
            config = ConfigObj()
            config.filename = self.path
            config['csv'] = default
            config['sql'] = default
            config.write()
            self.file_exists = True
            self.parse()

    def clean(self):
        settings = self.settings
        for keyword in settings:
            stop_words = "true false True False".split()
            value = settings[keyword]
            
            if value == 'true' or value == "True":
                settings[keyword] = True
                
            if value == 'false' or value == "False":
                settings[keyword] = False





try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup
    
import os
def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()
    
setup(
    name = "flashcards",
    version = "2.4",
    author = "Jose Luis Naranjo Gomez",
    author_email = "luisnaranjo733@hotmail.com",
    description = ("A simple command line flashcards utility, similar to physical flashcards."),
    license = "GNU GPL",
    install_requires= ['argparse','configobj',],
    entry_points = {
    'console_scripts': ['flashcards = flashcards.flashcards:main']
    },
    package_data = {'': ['*.txt']},
    keywords = "study flashcard replacement command line utility",
    url = "https://launchpad.net/pyflashcards",
    packages=['flashcards'],
    long_description=read('README.txt'),
    classifiers=[
        "License :: OSI Approved :: GNU General Public License (GPL)",
        "Topic :: Utilities",
    ],
)
    



#Copyright (c) 2012 Jose Luis Naranjo Gomez
#    This file is part of Flashcards
#
#    Flashcards is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    Flashcards is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Flashcards.  If not, see <http://www.gnu.org/licenses/>.

import os
import csv
import configure

cwd = os.getcwd()
data_path = os.path.join(configure.ROOT,"flashcards.csv")

#Creates a data.csv file in the current working directory if it does not already exist.


class reader(object):
    """This class actually quizzes the user. It parses from data.csv which is created in the current working directory.
    It runs itself, so you just need to call reader() and it will read the data file in the cwd and quiz the user on it.
    """
    
    def __init__(self):
        open(data_path,'a')
        self.txt = open(data_path, 'r')
        self.reader = csv.reader(self.txt, delimiter=",")
        self.QNA = self.load(data_path) #Parses the information in ./data.csv and stores it in a dict.
        empty = self.check_for_empty_files()
        if empty:
            print "="*72
            print "The data.csv file is empty!"
        #self.start() #Gets the ball rolling.
        
    def msg(self,message):
        print "="*72
        print message
        
    def load(self,path):
        """Loads a CSV file returns a dict of answers/questions"""
        #Thanks to ath0 (http://www.reddit.com/user/ath0) who wrote this method from http://reddit.com/r/learnpython
        
        dataset = dict()
        with open(path, 'r') as f:
            for line in f.readlines():
                split_line = line.split(',')
                question = split_line[0]
                answers = split_line[1:]
                dataset[question] = answers
        return dataset
        
    def start(self):
        for q in self.QNA:
            question = q
            answers = self.QNA[q]
            
            if not question or not answers:
                continue
            
            self.msg("Question:\t%s" % question)
            attempt = raw_input("> ")
            
            for answer in answers:
                if attempt == answer:
                    correct = True
                    break
                else:
                    correct = False
            
            if correct:
                print "Correct!"
            if not correct:
                print "The correct answer was:"
                if len(answers) > 1:
                    print "\tany of the following:"
                    
                print "\t",' | '.join(answers)
                
        #print "="*72
        
    def check_for_empty_files(self):
        txt = self.txt.readlines()
        empty = True
        for line in txt:
            if line:
                empty = False
        return empty
                
#--------------------------------------------------------------------------------------------------------------------------------

class writer(object):
    """This class appends sets of questions and answers into the data.csv file
    in the current working directory. The reader() class above uses this file."""
    
    def __init__(self):
        open(data_path,'a')
        #File IO object in either 'a' or 'w' mode.
        self.txt = open(data_path,'a')
        #KEY is a list of tuples with strings in them. Each tuple is a pair of question and answer.
        self.KEY = self.get_key() #Gets the questions and answers from the user and stores them in self.KEY for self.start()
        #self.start() #Gets the ball rolling. write() is the function that actually writes information to ./data.csv
        
    def start(self):
        writer = csv.writer(self.txt)
        for q in self.KEY: #group is a tuple of strings
            question = "%s," % q #string+comma
            answers = self.KEY[q] #string
            
            format = question+answers # String with comma separated values. First value is question.
            format = format.split(",") #Split the format string at each comma into a list.
            
            writer.writerow(format)
            self.txt.write("\n")
        self.txt.close()


    def get_key(self):
    
        qna = {}
        
        print "="*72
        print "NOTE:\tSeparate multiple choice answers with commas."
        
        while True:
            print "="*72
            
            question = raw_input("Question:\t ")
            
            if question == 'exit' or question == 'end':
                break
            
            answer = raw_input("Answer/s:\t")
            if answer == 'exit' or answer == 'end':
                break
                

            qna[question] = answer
            
        print "\n"
        return qna
        
        
    def get_mode(self):
        print "1: Edit mode"
        print "2: Over-write mode"
        
        mode = raw_input("> ")
        
        cwd = os.getcwd()
        data_path = os.path.join(cwd, 'data.csv')
        txt = open(data_path,'a')
        if mode == '1' or mode == 'edit mode':
            txt = open(data_path,'a')
            mode = 'edit'
        if mode == '2' or mode == 'over-write mode':
            txt = open(data_path,'w')
            mode = 'over-write'
            
        print "Opening %s in %s mode..." % (os.path.join(os.getcwd(), 'data.csv'), mode)

        return txt
        

